# Spatial transcriptomics

```{toctree}
:maxdepth: 1

notebooks/DestVI_tutorial
notebooks/DestVI_in_R
notebooks/gimvi_tutorial
notebooks/tangram_scvi_tools
notebooks/stereoscope_heart_LV_tutorial
notebooks/cell2location_lymph_node_spatial_tutorial
```
